@@ -37,6 +37,8 @@ def ddt(cls):
                     test_desc = case_data.get("title")
                 elif isinstance(case_data, dict) and case_data.get("desc"):
                     test_desc = case_data.get("desc")
+                elif hasattr(case_data, 'title'):
+                    test_desc = case_data.title
                 else:
                     test_desc = func.__doc__
                 func2 = _update_func(new_test_name, case_data, test_desc, func)
@@ -83,6 +85,7 @@ def json_data(file_path):
     :param file_path: json文件路径
     :return:
     """
+
     def wrapper(func):
         try:
             with open(file_path, "r", encoding="utf-8") as f:
