@@ -1,3 +1,4 @@
+# encoding=utf-8
 """
 ============================
 Author:柠檬班-木森
@@ -5,24 +6,19 @@ Time:2020/7/7   14:47
 E-mail:3247119728@qq.com
 Company:湖南零檬信息技术有限公司
 ============================
-
-本模块主要是为了解决unittest运行测试用例的生成HTML报告的测试问题，同时扩展了邮件发送等功能
-该模块预留了两个入口，
-
-注意点：
-使用起来非常简单，只需要调用TestRunner的run方法即可执行测试用例，运行的时候可通过参数指定开启的线程数量
-
 """
 import os
 import unittest
 import time
 from concurrent.futures.thread import ThreadPoolExecutor
-from unittestreport.core.sendEmail import SendEmail
-from unittestreport.core.testResult import TestResult, ReRunResult
-from unittestreport.core.dingtalk import DingTalk
+from ..core.testResult import TestResult, ReRunResult
+from ..core.resultPush import DingTalk, WeiXin, SendEmail
+
 from jinja2 import Environment, FileSystemLoader
 import copy
 
+Load = unittest.defaultTestLoader
+
 
 class TestRunner():
     """unittest运行程序"""
@@ -32,7 +28,7 @@ class TestRunner():
                  report_dir=".",
                  title='测试报告',
                  tester='木森',
-                 desc="XX项目测试生产的报告",
+                 desc="XX项目测试生成的报告",
                  templates=1
                  ):
         """
@@ -131,8 +127,8 @@ class TestRunner():
         self.test_result = test_result
         return test_result
 
-    def __get_dingtalk_content(self):
-        """获取钉钉通知的内容"""
+    def __get_notice_content(self):
+        """获取通知的内容"""
         template_path = os.path.join(os.path.dirname(__file__), '../templates')
         env = Environment(loader=FileSystemLoader(template_path))
         res_text = env.get_template('dingtalk.md').render(self.test_result)
@@ -197,14 +193,17 @@ class TestRunner():
         :return:
         """
         except_info = []
+        num = 0
         for i in self.result:
             for texts in i.failures:
                 t, content = texts
-                except_info.append("用例【{}】执行失败，失败信息如下：".format(t._testMethodDoc))
+                num += 1
+                except_info.append("*{}、用例【{}】执行失败*，\n失败信息如下：".format(num, t._testMethodDoc))
                 except_info.append(content)
             for texts in i.errors:
+                num += 1
                 t, content = texts
-                except_info.append("用例【{}】执行错误，错误信息如下：".format(t._testMethodDoc))
+                except_info.append("*{}、用例【{}】执行错误*，\n错误信息如下：".format(num, t._testMethodDoc))
                 except_info.append(content)
         except_str = "\n".join(except_info)
         return except_str
@@ -218,15 +217,13 @@ class TestRunner():
         :param atMobiles: （非必传，list类型）发送通知钉钉中要@人的手机号列表，如：[137xxx,188xxx]
         :param isatall: 是否@所有人，默认为False,设为True则会@所有人
         :param except_info:是否发送未通过用例的详细信息，默认为False，设为True则会发送失败用例的详细信息
-        :return:
+        :return:  发送成功返回 {"errcode":0,"errmsg":"ok"}  发送失败返回 {"errcode":错误码,"errmsg":"失败原因"}
         """
-        # 获取用例执行的结果,转换为md格式
-        res_text = self.__get_dingtalk_content()
-        # 判断是否需要发送错误用例的信息
+
+        res_text = self.__get_notice_content()
         if except_info:
-            res_text += '### 未通过用例详情：\n'
+            res_text += '\n ### 未通过用例详情：\n'
             res_text += self.get_except_info()
-        # 构建通知内容
         data = {
             "msgtype": "markdown",
             "markdown": {
@@ -239,4 +236,28 @@ class TestRunner():
             }
         }
         ding = DingTalk(url=url, data=data, secret=secret)
-        ding.send_info()
+        response = ding.send_info()
+        return response.json()
+
+    def weixin_notice(self, chatid, access_token=None, corpid=None, corpsecret=None):
+        """
+        测试结果推送到企业微信群，【access_token】和【corpid，corpsecret】至少要传一种
+        可以传入access_token ,也可以传入（corpid，corpsecret）来代替access_token
+        :param chatid: 企业微信群ID
+        :param access_token: 调用企业微信API接口的凭证
+        :param corpid: 企业ID
+        :param corpsecret:应用的凭证密钥
+        :return:
+        """
+        # 获取通知结果
+        res_text = self.__get_notice_content()
+        data = {
+            "chatid": chatid,
+            "msgtype": "markdown",
+            "markdown": {
+                "content": res_text
+            }
+        }
+        wx = WeiXin(access_token=access_token, corpid=corpid, corpsecret=corpsecret)
+        response = wx.send_info(data=data)
+        return response
